package com.ruoyi.system.service.impl.projectV2;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.projectV2.ZsyzFj;
import com.ruoyi.system.domain.projectV2.ZsyzSbbzb;
import com.ruoyi.system.mapper.projectV2.XmProjectInvestorMapper;
import com.ruoyi.system.mapper.projectV2.XmProjectPersionMapper;
import com.ruoyi.system.mapper.projectV2.ZsyzFjMapper;
import com.ruoyi.system.mapper.projectV2.ZsyzSbbzbMapper;
import com.ruoyi.system.service.projectV2.IZsyzSbbzbService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 招商引资_申报_首谈信息_主Service业务层处理
 *
 * @author boman
 * @date 2023-02-23
 */
@Service
public class ZsyzSbbzbServiceImpl implements IZsyzSbbzbService {
    @Autowired
    private ZsyzSbbzbMapper zsyzSbbzbMapper;

    @Autowired
    private ZsyzFjMapper zsyzFjMapper;

    @Autowired
    private XmProjectPersionMapper xmProjectPersionMapper;

    @Autowired
    private XmProjectInvestorMapper xmProjectInvestorMapper;

    /**
     * 查询招商引资_申报_首谈信息_主
     *
     * @param id 招商引资_申报_首谈信息_主ID
     * @return 招商引资_申报_首谈信息_主
     */
    @Override
    @Transactional
    public ZsyzSbbzb selectZsyzSbbzbById(Long id)
    {
        ZsyzSbbzb zsyzSbbzb = zsyzSbbzbMapper.selectZsyzSbbzbById(id);
        ZsyzFj zsyzFj = new ZsyzFj();
        zsyzFj.setSourceId(id);
        List<ZsyzFj> zsyzFjList = zsyzFjMapper.selectZsyzFjList(zsyzFj);
        if (zsyzFjList != null && zsyzFjList.size() > 0){
            zsyzSbbzb.setZsyzFjList(zsyzFjList);
        }
        return zsyzSbbzb;
    }

    /**
     * 查询招商引资_申报_首谈信息_主列表
     *
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 招商引资_申报_首谈信息_主
     */
    @Override
    public List<ZsyzSbbzb> selectZsyzSbbzbList(ZsyzSbbzb zsyzSbbzb) {
        return zsyzSbbzbMapper.selectZsyzSbbzbList(zsyzSbbzb);
    }

    /**
     * 新增招商引资_申报_首谈信息_主
     *
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 结果
     */
    @Override
    @Transactional
    public int insertZsyzSbbzb(ZsyzSbbzb zsyzSbbzb)
    {
        //获取当前人员信息
        SysUser user = SecurityUtils.getLoginUser().getUser();
        zsyzSbbzb.setCreateTime(DateUtils.getNowDate());
        zsyzSbbzb.setUserId(user.getUserId());
        int count = zsyzSbbzbMapper.insertZsyzSbbzb(zsyzSbbzb);
        //保存附件信息
        List<ZsyzFj> zsyzFjList = zsyzSbbzb.getZsyzFjList();
        for (ZsyzFj zsyzFj : zsyzFjList) {
            zsyzFj.setSourceId(zsyzSbbzb.getId());
            zsyzFj.setType("1");
            zsyzFj.setXmId(zsyzSbbzb.getId());
            zsyzFj.setXmbh(zsyzSbbzb.getXmbh());
            zsyzFjMapper.insertZsyzFj(zsyzFj);
        }
        //将项目投资方-自然人、企业两张表赋值项目ID
        xmProjectPersionMapper.updateXmProjectPersionByXmbh(zsyzSbbzb.getId(),zsyzSbbzb.getXmbh());
        xmProjectInvestorMapper.updateXmProjectInvestorByXmbh(zsyzSbbzb.getId(),zsyzSbbzb.getXmbh());
        return count;
    }

    /**
     * 修改招商引资_申报_首谈信息_主
     *
     * @param zsyzSbbzb 招商引资_申报_首谈信息_主
     * @return 结果
     */
    @Override
    @Transactional
    public int updateZsyzSbbzb(ZsyzSbbzb zsyzSbbzb)
    {

        zsyzSbbzb.setUpdateTime(DateUtils.getNowDate());
        int count = zsyzSbbzbMapper.updateZsyzSbbzb(zsyzSbbzb);
        //修改附件
        if(zsyzSbbzb.getZsyzFjList()!=null && zsyzSbbzb.getZsyzFjList().size()>0){
            //先删除相关附件
            zsyzFjMapper.deleteZsyzFjBySourceId(zsyzSbbzb.getId());
            //再将文件新增进数据库
            List<ZsyzFj> zsyzFjList = zsyzSbbzb.getZsyzFjList();
            for (ZsyzFj zsyzFj : zsyzFjList) {
                zsyzFj.setSourceId(zsyzSbbzb.getId());
                zsyzFj.setType("1");
                zsyzFj.setXmId(zsyzSbbzb.getId());
                zsyzFj.setXmbh(zsyzSbbzb.getXmbh());
                zsyzFjMapper.insertZsyzFj(zsyzFj);
            }
        }

        return count;
    }

    /**
     * 更新承接地信息
     *
     * @param zsyzSbbzb
     * @return
     */
    @Override
    public int updateZsyzSbbzbCjd(ZsyzSbbzb zsyzSbbzb) {
        return zsyzSbbzbMapper.updateZsyzSbbzbCjd(zsyzSbbzb);
    }

    //线索暂存/终止接口
    @Override
    public int updateZsyzSbbzbForZc(ZsyzSbbzb zsyzSbbzb) {
        return zsyzSbbzbMapper.updateZsyzSbbzbForZc(zsyzSbbzb);
    }


    /**
     * 批量删除招商引资_申报_首谈信息_主
     *
     * @param ids 需要删除的招商引资_申报_首谈信息_主ID
     * @return 结果
     */
    @Override
    public int deleteZsyzSbbzbByIds(Long[] ids) {
        return zsyzSbbzbMapper.deleteZsyzSbbzbByIds(ids);
    }

    /**
     * 删除招商引资_申报_首谈信息_主信息
     *
     * @param id 招商引资_申报_首谈信息_主ID
     * @return 结果
     */
    @Override
    public int deleteZsyzSbbzbById(Long id) {
        return zsyzSbbzbMapper.deleteZsyzSbbzbById(id);
    }

    @Override
    public List<ZsyzSbbzb> selectZsyzSbbzbListDc(ZsyzSbbzb zsyzSbbzb) {
        return zsyzSbbzbMapper.selectZsyzSbbzbListDc(zsyzSbbzb);
    }
}
